async def monitor_sources(bot):
    """Monitor sources for changes and send updates."""
    global source_states, target_chat_id
    
    print("\nStarting source monitoring...")
    
    # Wait for chat ID
    while target_chat_id is None:
        await asyncio.sleep(5)
        continue
        
    while True:
        try:
            # Check each source
            for source in MONITOR_SOURCES:
                try:
                    # Fetch current content
                    current_content = None
                    async with aiohttp.ClientSession() as session:
                        async with session.get(source) as response:
                            if response.status == 200:
                                current_content = await response.text()
                    
                    if current_content:
                        current_content = current_content.strip()
                        
                        # Initialize state if needed
                        if source not in source_states:
                            source_states[source] = {
                                "lines_seen": set(),
                                "last_check": ""
                            }
                            
                        state = source_states[source]
                        
                        # Split into lines and find new ones
                        current_lines = set(current_content.splitlines())
                        new_lines = current_lines - state["lines_seen"]
                        
                        if new_lines:
                            # Sort new lines to maintain order
                            new_content = "\n".join(sorted(new_lines))
                            
                            # Add header and send
                            header = SOURCE_CONFIGS[source]["header"]
                            message = f"{header}\n\n{new_content}"
                            
                            await bot.send_message(chat_id=target_chat_id, text=message)
                            print(f"Sent {len(new_lines)} new lines from {source}")
                            
                            # Update state
                            state["lines_seen"].update(new_lines)
                            state["last_check"] = datetime.now().strftime('%Y-%m-%d %H:%M:%S')
                            save_state()
                            
                except Exception as e:
                    print(f"Error checking {source}: {e}")
                    
            await asyncio.sleep(1)
                    
        except Exception as e:
            print(f"Monitor error: {e}")
            await asyncio.sleep(5)